@@ -27,10 +27,10 @@
 #include <telepathy-glib/telepathy-glib.h>
 
 #include <telepathy-logger/event.h>
+#include <telepathy-logger/log-walker.h>
 
 G_BEGIN_DECLS
 #define TPL_TYPE_LOG_MANAGER  (tpl_log_manager_get_type ())
-#define TPL_TYPE_LOG_SEARCH_HIT (_tpl_log_manager_search_hit_get_type ())
 #define TPL_LOG_MANAGER(o)  (G_TYPE_CHECK_INSTANCE_CAST ((o), TPL_TYPE_LOG_MANAGER, TplLogManager))
 #define TPL_LOG_MANAGER_CLASS(k)  (G_TYPE_CHECK_CLASS_CAST ((k), TPL_TYPE_LOG_MANAGER, TplLogManagerClass))
 #define TPL_IS_LOG_MANAGER(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), TPL_TYPE_LOG_MANAGER))
@@ -67,6 +67,7 @@ typedef struct
 /**
  * TplEventTypeMask:
  * @TPL_EVENT_MASK_TEXT: Mask to #TplTextEvent
+ * @TPL_EVENT_MASK_CALL: Mask to #TplCallEvent
  * @TPL_EVENT_MASK_ANY: Special value to select all type of #TplEvent
  *
  * Mask used to filter type of #TplEvent returned.
@@ -78,7 +79,6 @@ typedef enum
   TPL_EVENT_MASK_ANY          = 0xffff
 } TplEventTypeMask;
 
-
 /**
  * TplLogSearchHit:
  * @account: the #TpAccount
@@ -87,18 +87,18 @@ typedef enum
  *
  * Represent the context where the search has results.
  */
-typedef struct
+typedef struct _TplLogSearchHit TplLogSearchHit;
+struct _TplLogSearchHit
 {
   TpAccount *account;
   TplEntity *target;
   GDate *date;
-} TplLogSearchHit;
+};
 
 typedef gboolean (*TplLogEventFilter) (TplEvent *event,
     gpointer user_data);
 
 GType tpl_log_manager_get_type (void);
-GType _tpl_log_manager_search_hit_get_type (void);
 
 TplLogManager *tpl_log_manager_dup_singleton (void);
 
@@ -147,6 +147,13 @@ gboolean tpl_log_manager_get_filtered_events_finish (TplLogManager *self,
     GList **events,
     GError **error);
 
+TplLogWalker *tpl_log_manager_walk_filtered_events (TplLogManager *manager,
+    TpAccount *account,
+    TplEntity *target,
+    gint type_mask,
+    TplLogEventFilter filter,
+    gpointer filter_data);
+
 void tpl_log_manager_get_entities_async (TplLogManager *self,
     TpAccount *account,
     GAsyncReadyCallback callback,
