@@ -23,7 +23,9 @@
 
 #include <telepathy-logger/entity.h>
 #include <telepathy-logger/text-event.h>
+#include <telepathy-logger/call-event.h>
 #include <telepathy-logger/event.h>
 #include <telepathy-logger/log-manager.h>
+#include <telepathy-logger/log-walker.h>
 
 #endif
